Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterRoutesTestService ¶
func RegisterRoutesTestService(router wrouter.Router, impl TestService) error
RegisterRoutesTestService registers handlers for the TestService endpoints with a witchcraft wrouter. This should typically be called in a witchcraft server's InitFunc. impl provides an implementation of each endpoint, which can assume the request parameters have been parsed in accordance with the Conjure specification.
Types ¶
type CustomObject ¶
type CustomObject struct {
Data []byte `json:"data"`
}
func (CustomObject) MarshalJSON ¶
func (o CustomObject) MarshalJSON() ([]byte, error)
func (CustomObject) MarshalYAML ¶
func (o CustomObject) MarshalYAML() (interface{}, error)
func (*CustomObject) UnmarshalJSON ¶
func (o *CustomObject) UnmarshalJSON(data []byte) error
func (*CustomObject) UnmarshalYAML ¶
func (o *CustomObject) UnmarshalYAML(unmarshal func(interface{}) error) error
type RidAlias ¶
type RidAlias rid.ResourceIdentifier
func (RidAlias) MarshalText ¶
func (RidAlias) MarshalYAML ¶
func (*RidAlias) UnmarshalText ¶
func (*RidAlias) UnmarshalYAML ¶
type StringAlias ¶
type StringAlias string
type TestService ¶
type TestService interface {
Echo(ctx context.Context) error
PathParam(ctx context.Context, paramArg string) error
PathParamAlias(ctx context.Context, paramArg StringAlias) error
PathParamRid(ctx context.Context, paramArg rid.ResourceIdentifier) error
PathParamRidAlias(ctx context.Context, paramArg RidAlias) error
Bytes(ctx context.Context) (CustomObject, error)
Binary(ctx context.Context) (io.ReadCloser, error)
}
type TestServiceClient ¶
type TestServiceClient interface {
Echo(ctx context.Context) error
PathParam(ctx context.Context, paramArg string) error
PathParamAlias(ctx context.Context, paramArg StringAlias) error
PathParamRid(ctx context.Context, paramArg rid.ResourceIdentifier) error
PathParamRidAlias(ctx context.Context, paramArg RidAlias) error
Bytes(ctx context.Context) (CustomObject, error)
Binary(ctx context.Context) (io.ReadCloser, error)
}
func NewTestServiceClient ¶
func NewTestServiceClient(client httpclient.Client) TestServiceClient
Click to show internal directories.
Click to hide internal directories.